==> open-xchange-documents-ui_7.8.3.orig.tar.bz2: open-xchange-documents-ui-7.8.3/ui/apps/io.ox/office/drawinglayer/model/shapemodel.js <==
/**
 * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
 * LICENSE. This work is protected by copyright and/or other applicable
 * law. Any use of the work other than as authorized under this license
 * or copyright law is prohibited.
 *
 * http://creativecommons.org/licenses/by-nc-sa/2.5/
 *
 * Copyright (C) 2016 OX Software GmbH
 * Mail: info@open-xchange.com
 *
 * @author Daniel Rentz <daniel.rentz@open-xchange.com>
 */

define('io.ox/office/drawinglayer/model/shapemodel', [
    'io.ox/office/drawinglayer/model/drawingmodel'
], function (DrawingModel) {

    'use strict';

    // class ShapeModel =======================================================

    /**
     * The model of a shape object.
     *
     * @constructor
     *
     * @extends DrawingModel
     *
     * @param {EditModel} docModel
     *  The document model containing this drawing object.
     *
     * @param {Object} [initAttributes]
     *  An attribute set with initial formatting attributes for the object.
     */
    function ShapeModel(docModel, initAttributes) {

        // base constructor ---------------------------------------------------

        DrawingModel.call(this, docModel, 'shape', initAttributes, { families: 'shape fill line' });

        // initialization -----------------------------------------------------

        // destroy all class members on destruction
        this.registerDestructor(function () {
            docModel = initAttributes = null;
        });

    } // class ShapeModel

    // exports ================================================================

    // derive this class from class DrawingModel
    return DrawingModel.extend({ constructor: ShapeModel });

});

==> open-xchange-documents-ui_7.10.1.orig.tar.bz2: open-xchange-documents-ui-7.10.1/ui/apps/io.ox/office/drawinglayer/model/shapemodel.js <==
/**
 * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
 * LICENSE. This work is protected by copyright and/or other applicable
 * law. Any use of the work other than as authorized under this license
 * or copyright law is prohibited.
 *
 * http://creativecommons.org/licenses/by-nc-sa/2.5/
 *
 * Copyright (C) 2016 OX Software GmbH
 * Mail: info@open-xchange.com
 *
 * @author Daniel Rentz <daniel.rentz@open-xchange.com>
 */

define('io.ox/office/drawinglayer/model/shapemodel', [
    'io.ox/office/drawinglayer/model/drawingmodel'
], function (DrawingModel) {

    'use strict';

    // class ShapeModel =======================================================

    /**
     * The model of a shape object.
     *
     * @constructor
     *
     * @extends DrawingModel
     *
     * @param {DrawingCollection} parentCollection
     *  The parent drawing collection that will contain this drawing object.
     *
     * @param {Object} [initAttributes]
     *  An attribute set with initial formatting attributes for the object.
     */
    var ShapeModel = DrawingModel.extend({ constructor: function (parentCollection, initAttributes) {

        // base constructor ---------------------------------------------------

        DrawingModel.call(this, parentCollection, 'shape', initAttributes, { families: 'shape geometry fill line character', rotatable: true });

        // initialization -----------------------------------------------------

        // destroy all class members on destruction
        this.registerDestructor(function () {
            parentCollection = initAttributes = null;
        });

    } }); // class ShapeModel

    // exports ================================================================

    return ShapeModel;

});
